/*
 * $Id: imap_list.h 8378 2010-02-25 22:43:57Z dothebart $
 */

/*
 * In the extended form of LIST the client is allowed to specify
 * multiple match patterns.  How many will we allow?
 */
#define MAX_PATTERNS 20

void imap_list(int num_parms, ConstStr *Params);
